@@ -21,7 +21,7 @@ import subprocess
 import sys
 import tarfile
 
-from reprounzip.common import Package, load_config
+from reprounzip.common import Package, load_config, record_usage
 from reprounzip import signals
 from reprounzip.unpackers.common import COMPAT_OK, COMPAT_MAYBE, \
     composite_action, target_must_exist, make_unique_name, shell_escape, \
@@ -36,6 +36,9 @@ def select_image(runs):
     distribution = distribution.lower()
     architecture = runs[0]['architecture']
 
+    record_usage(docker_select_box='%s;%s;%s' % (distribution, version,
+                                                 architecture))
+
     if architecture == 'i686':
         logging.info("wanted architecture was i686, but we'll use x86_64 with "
                      "Docker")
@@ -106,6 +109,7 @@ def docker_setup_create(args):
     runs, packages, other_files = load_config(target / 'config.yml', True)
 
     if args.base_image:
+        record_usage(docker_explicit_base=True)
         target_distribution = None
         base_image = args.base_image[0]
     else:
@@ -128,6 +132,10 @@ def docker_setup_create(args):
         packages = [pkg for pkg in packages if not pkg.packfiles]
         # FIXME : Right now, we need 'sudo' to be available (and it's not
         # necessarily in the base image)
+        if packages:
+            record_usage(docker_install_pkgs=True)
+        else:
+            record_usage(docker_install_pkgs="sudo")
         packages += [Package('sudo', None, packfiles=False)]
         if packages:
             installer = select_installer(pack, runs, target_distribution)
@@ -362,9 +370,12 @@ class ContainerDownloader(FileDownloader):
         # a file name (#4272)
         tmpdir = Path.tempdir(prefix='reprozip_docker_output_')
         try:
-            subprocess.check_call(['docker', 'cp',
-                                   self.container + b':' + remote_path.path,
-                                   tmpdir.path])
+            ret = subprocess.call(['docker', 'cp',
+                                  self.container + b':' + remote_path.path,
+                                  tmpdir.path])
+            if ret != 0:
+                logging.critical("Can't get output file: %s", remote_path)
+                sys.exit(1)
             (tmpdir / remote_path.name).copyfile(local_path)
         finally:
             tmpdir.rmtree()
@@ -469,6 +480,11 @@ def setup(parser, **kwargs):
         $ reprounzip docker download . results:/home/user/theresults.txt
         $ cd ..; reprounzip docker destroy experiment
 
+    Upload specifications are either:
+      :input_id             restores the original input file from the pack
+      filename:input_id     replaces the input file with the specified local
+                            file
+
     Download specifications are either:
       output_id:            print the output file to stdout
       output_id:filename    extracts the output file to the corresponding local
